==> plantuml-libs-9.0.0.tgz: package/distribution/simpleicons-7/F/Fraunhofergesellschaft.md <==
# Fraunhofergesellschaft


```text
simpleicons-7/F/Fraunhofergesellschaft
```

```text
include('simpleicons-7/F/Fraunhofergesellschaft')
```



| Illustration | Fraunhofergesellschaft |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/F/Fraunhofergesellschaft.png) | ![illustration for Fraunhofergesellschaft](../../simpleicons-7/F/Fraunhofergesellschaft.Local.png) |




## Fraunhofergesellschaft

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Fraunhofergesellschaft
include('simpleicons-7/F/Fraunhofergesellschaft')

' renders the element
Fraunhofergesellschaft('Fraunhofergesellschaft', 'Fraunhofergesellschaft', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Fraunhofergesellschaft
include('simpleicons-7/F/Fraunhofergesellschaft')

' renders the element
Fraunhofergesellschaft('Fraunhofergesellschaft', 'Fraunhofergesellschaft', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/simpleicons-7/F/Fraunhofergesellschaft.md <==
# Fraunhofergesellschaft


```text
simpleicons-7/F/Fraunhofergesellschaft
```

```text
include('simpleicons-7/F/Fraunhofergesellschaft')
```



| Illustration | Fraunhofergesellschaft |
| :---: | :---: |
| ![illustration for Illustration](../../simpleicons-7/F/Fraunhofergesellschaft.png) | ![illustration for Fraunhofergesellschaft](../../simpleicons-7/F/Fraunhofergesellschaft.Local.png) |




## Fraunhofergesellschaft

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Fraunhofergesellschaft
include('simpleicons-7/F/Fraunhofergesellschaft')

' renders the element
Fraunhofergesellschaft('Fraunhofergesellschaft', 'Fraunhofergesellschaft', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('simpleicons-7/bootstrap')

' loads the Item which embeds the element Fraunhofergesellschaft
include('simpleicons-7/F/Fraunhofergesellschaft')

' renders the element
Fraunhofergesellschaft('Fraunhofergesellschaft', 'Fraunhofergesellschaft', 'an optional tech label', 'an optional description')
@enduml
```
